Name:          liblinear
Version:       2.48
Release:       1mamba
Summary:       A library for solving large-scale regularized linear classification and regression
Group:         System/Libraries
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://www.csie.ntu.edu.tw/~cjlin/liblinear/
Source:        https://github.com/cjlin1/liblinear.git/v196/liblinear-%{version}.tar.bz2
Patch0:        liblinear-1.96.makefile.patch
License:       BSD
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libblas-devel
BuildRequires: libgcc
BuildRequires: libstdc++6-devel
## AUTOBUILDREQ-END
BuildRequires: gcc-c++

%description
liblinear is a simple package for solving large-scale regularized linear classification and regression.
It currently supports:
 - L2-regularized logistic regression/L2-loss support vector classification/L1-loss support vector classification
 - L1-regularized L2-loss support vector classification/L1-regularized logistic regression
 - L2-regularized L2-loss support vector regression/L1-loss support vector regression.

%package devel
Group:         Development/Libraries
Summary:       Development files for %{name}
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}
Requires:      pkg-config

%description devel
This package contains libraries and header files for developing applications that use %{name}.

%package tools
Group:         Applications/Mathematics
Summary:       Utility applications for %{name}
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}

%description tools
This package contains utility applications for %{name}.

%package -n python-%{name}
Group:         Development/Libraries/Python
Summary:       Python bindings for %{name}
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}
Requires:      python

%description -n python-%{name}
%{summary}.


%prep
%setup -q
%patch 0 -p1

rm -rf blas/ windows/

# add pkg-config file
cat << _EOF >> %{name}.pc
Name: %{name}
Description: Library for Large Linear Classification
URL: %{url}
Version: 2.48

prefix=%{_prefix}
includedir=%{_includedir}

Cflags: -I\${includedir}/liblinear
Libs: -llinear
_EOF

%build
CFLAGS="%optflags -O3"; export CFLAGS
%make all lib

python -m compileall -l python

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

mkdir -p %{buildroot}%{_bindir}
install -m 0755 predict %{buildroot}%{_bindir}/%{name}-predict
install -m 0755 train %{buildroot}%{_bindir}/%{name}-train

mkdir -p %{buildroot}%{_libdir}
install liblinear.so* %{buildroot}%{_libdir}/
mkdir -p %{buildroot}%{_libdir}/pkgconfig
install -m 0644 %{name}.pc %{buildroot}%{_libdir}/pkgconfig/

mkdir -p %{buildroot}%{_includedir}/%{name}
install -m 0644 {linear,tron}.h %{buildroot}%{_includedir}/%{name}/

mkdir -p %{buildroot}%{python_sitearch}
install -m 0644 python/*.py* %{buildroot}%{python_sitearch}/

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"


%files
%defattr(-,root,root)
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%doc README

%files tools
%defattr(-,root,root)
%{_bindir}/%{name}-predict
%{_bindir}/%{name}-train

#%files -n python-%{name}
#%defattr(-,root,root)
#%{python_sitearch}/*

%changelog
* Sun Jan 05 2025 Automatic Build System <autodist@openmamba.org> 2.48-1mamba
- automatic version update by autodist

* Mon Jul 10 2023 Automatic Build System <autodist@mambasoft.it> 2.47-1mamba
- automatic version update by autodist

* Sat Feb 18 2023 Automatic Build System <autodist@mambasoft.it> 2.46-1mamba
- automatic version update by autodist

* Fri Aug 12 2022 Automatic Build System <autodist@mambasoft.it> 2.45-1mamba
- automatic version update by autodist

* Sat Apr 02 2022 Automatic Build System <autodist@mambasoft.it> 2.44-1mamba
- automatic version update by autodist

* Fri Feb 26 2021 Automatic Build System <autodist@mambasoft.it> 2.43-1mamba
- automatic version update by autodist

* Sun Feb 07 2021 Automatic Build System <autodist@mambasoft.it> 2.42-1mamba
- automatic version update by autodist

* Sun Mar 22 2015 Davide Madrisan <davide.madrisan@gmail.com> 1.96-2mamba
- python-%{name}: provide the .pyc files

* Sun Mar 22 2015 Davide Madrisan <davide.madrisan@gmail.com> 1.96-1mamba
- package created by autospec
